@@ -2,15 +2,17 @@ package Proc::Launcher;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.35'; # VERSION
+our $VERSION = '0.0.36'; # VERSION
 
-use Mouse;
+use Moo;
+use MooX::Types::MooseLike::Base qw(Bool Str Int InstanceOf);
 
 #_* Libraries
 
 use File::Path;
 use File::Tail;
 use POSIX qw(setsid :sys_wait_h);
+use Privileges::Drop;
 
 #_* POD
 
@@ -21,7 +23,7 @@ Proc::Launcher - yet another forking process controller
 
 =head1 VERSION
 
-version 0.0.35
+version 0.0.36
 
 =head1 SYNOPSIS
 
@@ -186,7 +188,7 @@ Enable debugging messages to STDOUT.  This attribute is read/write.
 
 =cut
 
-has 'debug'        => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'debug'        => ( is => 'rw', isa => Bool, default => 0 );
 
 =item daemon_name => 'somename'
 
@@ -195,7 +197,7 @@ the log file, pid file, etc.
 
 =cut
 
-has 'daemon_name'  => ( is => 'ro', isa => 'Str', required => 1 );
+has 'daemon_name'  => ( is => 'ro', isa => Str, required => 1 );
 
 =item context => $data
 
@@ -214,7 +216,7 @@ start_method will be called on the object.
 
 =cut
 
-has 'class'        => ( is => 'ro', isa => 'Str' );
+has 'class'        => ( is => 'ro', isa => Str );
 
 =item start_method => 'start_me'
 
@@ -234,7 +236,7 @@ Specify the directory where the pid file should live.
 =cut
 
 has 'pid_dir'      => ( is => 'ro',
-                        isa => 'Str',
+                        isa => Str,
                         lazy => 1,
                         default => sub {
                             my $dir = join "/", $ENV{HOME}, "logs";
@@ -250,7 +252,7 @@ Name of the pid file.
 =cut
 
 has 'pid_file'     => ( is => 'ro',
-                        isa => 'Str',
+                        isa => Str,
                         lazy => 1,
                         default => sub {
                             my ( $self ) = @_;
@@ -267,7 +269,7 @@ not be started when start() is called.
 =cut
 
 has 'disable_file' => ( is => 'ro',
-                        isa => 'Str',
+                        isa => Str,
                         lazy => 1,
                         default => sub {
                             my ( $self ) = @_;
@@ -284,7 +286,7 @@ and stderr redirected to this log file.
 =cut
 
 has 'log_file'     => ( is => 'ro',
-                        isa => 'Str',
+                        isa => Str,
                         lazy => 1,
                         default => sub {
                             my $self = shift;
@@ -294,7 +296,7 @@ has 'log_file'     => ( is => 'ro',
                     );
 
 has 'file_tail'    => ( is => 'ro',
-                        isa => 'File::Tail',
+                        isa => InstanceOf['File::Tail'],
                         lazy => 1,
                         default => sub {
                             my $self = shift;
@@ -319,7 +321,7 @@ then there's no use in enabling this option.
 =cut
 
 has 'pipe'         => ( is => 'ro',
-                        isa => 'Bool',
+                        isa => Bool,
                         default => 0,
                     );
 
@@ -330,7 +332,7 @@ Path to the named pipe.
 =cut
 
 has 'pipe_file'    => ( is => 'ro',
-                        isa => 'Str',
+                        isa => Str,
                         lazy => 1,
                         default => sub {
                             my $self = shift;
@@ -339,6 +341,32 @@ has 'pipe_file'    => ( is => 'ro',
                         },
                     );
 
+=item stop_signal => 1
+
+Signal to be send to stop a process. Default is 1 (HUP). If you
+want to control some other processes, e.g. redis you may have to send
+signal 15 (TERM) to stop the progress gracefully.
+
+=cut
+
+has 'stop_signal'    => ( is => 'rw',
+                        isa => Int,
+                        lazy => 1,
+                        default => 1
+                    );
+
+=item run_as => $user
+
+If defined, this process will be run as the specified user.
+This will probably only work if the parent script is run as
+root (or a superuser). Note, as we're changing the effective
+user of the process, perl will automatically turn on taint
+mode.
+
+=cut 
+
+has 'run_as'        => ( is => 'ro', isa => Str, required => 0 );
+
 #_* Methods
 
 =back
@@ -443,6 +471,8 @@ sub start {
 
         # this doesn't work on most platforms
         $0 = join " - ", "perl", "Proc::Launcher", $self->daemon_name;
+        
+        drop_privileges($self->run_as) if $self->run_as;
 
         print "\n\n", ">" x 77, "\n";
         print "Starting process: pid = $$: ", scalar localtime, "\n\n";
@@ -534,7 +564,7 @@ sub stop {
     my $pid = $self->pid();
 
     $self->_debug( "Killing process: $pid" );
-    my $status = kill 1 => $pid;
+    my $status = kill $self->stop_signal => $pid;
 
     return $status;
 }
@@ -897,8 +927,6 @@ sub _debug {
     }
 }
 
-no Mouse;
-
 1;
 
 __END__
@@ -971,4 +999,4 @@ LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\ No newline at end of file
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
