@@ -2,9 +2,10 @@ package Proc::Launcher::Manager;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.35'; # VERSION
+our $VERSION = '0.0.36'; # VERSION
 
-use Mouse;
+use Moo;
+use MooX::Types::MooseLike::Base qw(Bool Str HashRef InstanceOf);
 
 use Carp;
 use File::Path;
@@ -19,7 +20,7 @@ Proc::Launcher::Manager - manage multiple Proc::Launcher objects
 
 =head1 VERSION
 
-version 0.0.35
+version 0.0.36
 
 =head1 SYNOPSIS
 
@@ -100,12 +101,12 @@ with 'Proc::Launcher::Roles::Launchable';
 #_* Attributes
 
 has 'debug'      => ( is         => 'ro',
-                      isa        => 'Bool',
+                      isa        => Bool,
                       default    => 0,
                   );
 
 has 'pid_dir'    => ( is         => 'ro',
-                      isa        => 'Str',
+                      isa        => Str,
                       lazy       => 1,
                       default    => sub {
                           my $dir = join "/", $ENV{HOME}, "logs";
@@ -115,7 +116,7 @@ has 'pid_dir'    => ( is         => 'ro',
                   );
 
 has 'launchers'  => ( is         => 'rw',
-                      isa        => 'HashRef[Proc::Launcher]',
+                      isa        => HashRef[InstanceOf['Proc::Launcher']],
                   );
 
 
@@ -437,6 +438,4 @@ sub tail {
 
 =cut
 
-no Mouse;
-
-1;
\ No newline at end of file
+1;
