@@ -2,9 +2,9 @@ package Proc::Launcher::Roles::Launchable;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.35'; # VERSION
+our $VERSION = '0.0.36'; # VERSION
 
-use Mouse::Role;
+use Moo::Role;
 
 requires 'start';
 requires 'stop';
@@ -14,7 +14,6 @@ requires 'force_stop';
 requires 'is_running';
 
 
-no Mouse::Role;
 
 1;
 
@@ -27,11 +26,11 @@ Proc::Launcher::Roles::Launchable - defines an interface for launchers
 
 =head1 VERSION
 
-version 0.0.35
+version 0.0.36
 
 =head1 SYNOPSIS
 
-    use Mouse;
+    use Moo;
     with 'Proc::Launcher::Roles::Launchable';
 
 =head1 DESCRIPTION
@@ -76,4 +75,4 @@ LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\ No newline at end of file
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
