@@ -2,17 +2,18 @@ package Proc::Launcher::Supervisor;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.35'; # VERSION
+our $VERSION = '0.0.36'; # VERSION
 
-use Mouse;
+use Moo;
+use MooX::Types::MooseLike::Base qw(Bool Str Int InstanceOf HashRef);
 
 has 'monitor_delay' => ( is       => 'rw',
-                         isa      => 'Int',
+                         isa      => Int,
                          default  => 15,
                      );
 
 has 'manager'       => ( is       => 'rw',
-                         isa      => 'Proc::Launcher::Manager',
+                         isa      => InstanceOf['Proc::Launcher::Manager'],
                          required => 1,
                      );
 
@@ -27,8 +28,6 @@ sub monitor {
     }
 }
 
-no Mouse;
-
 1;
 
 __END__
@@ -40,7 +39,7 @@ Proc::Launcher::Supervisor - restart watched processes that have exited
 
 =head1 VERSION
 
-version 0.0.35
+version 0.0.36
 
 =head1 DESCRIPTION
 
@@ -104,4 +103,4 @@ LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\ No newline at end of file
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
